summaryrefslogtreecommitdiff
path: root/src/w32heap.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2012-07-29 01:18:29 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2012-07-29 01:18:29 -0700
commitb46a6a83b3c30d34aa6b80633394c74e6145291c (patch)
tree70cf89c43b7663acf77c2e54f2ed644d1eb18a4e /src/w32heap.c
parent72b255c7e7856eb0abefb1149211a8be519f6fef (diff)
Don't use the abbreviation "win" to refer to Windows (Bug#10421).
* lisp/org/ob-lilypond.el (ly-w32-ly-path): Rename from ly-win32-ly-path. (ly-w32-pdf-path): Rename from ly-win32-pdf-path. (ly-w32-midi-path): Rename from ly-win32-midi-path. (ly-determine-ly-path, ly-determine-pdf-path, ly-determine-midi-path): Check for "windows-nt", not "win32", in system-type. * src/regex.c (MAX_BUF_SIZE): Remove some incorrect and long-ago-commented-out code that talks about "WIN32". * src/w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95. All uses changed.
Diffstat (limited to 'src/w32heap.c')
-rw-r--r--src/w32heap.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/w32heap.c b/src/w32heap.c
index cc5e5cd2bf..e34021b109 100644
--- a/src/w32heap.c
+++ b/src/w32heap.c
@@ -1,4 +1,4 @@
/* Heap management routines for GNU Emacs on the Microsoft W32 API.
Copyright (C) 1994, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -66,7 +66,7 @@ cache_system_info (void)
w32_minor_version = version.info.minor;
if (version.info.platform & 0x8000)
- os_subtype = OS_WIN95;
+ os_subtype = OS_WINDOWS_95;
else
os_subtype = OS_NT;
@@ -79,7 +79,7 @@ cache_system_info (void)
GetVersionEx (&osinfo_cache);
w32_build_number = osinfo_cache.dwBuildNumber;
- if (os_subtype == OS_WIN95)
+ if (os_subtype == OS_WINDOWS_95)
w32_build_number &= 0xffff;
}
@@ -1,4 +1,4 @@
-/* Heap management routines for GNU Emacs on the Microsoft W32 API.
+/* Heap management routines for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1994, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.